#ifndef __TPM_SECURITY_H__
#define __TPM_SECURITY_H__

#include <err.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdint.h>
#include <stdbool.h>

struct TPMAlgorithm {
    char alg[16];
};

struct TPMSupportAlgorithm {
    uint32_t count;
    struct TPMAlgorithm  algs[128];
};

struct TPMTrustedRootData {
    char chipType[8];
    char chipVersion[8];
    char specVersion[8];
    char manufacturer[4];
    uint32_t nvDefined;
    struct TPMSupportAlgorithm supportAlg; 
};


struct TPMBootMeasureData{
    char time[64];    //度量时间
    char pname[256]; //度量进程名
    bool measure_result;
    int start_measure_error_number;    
};

struct TPMBootMeasureLog {
    uint32_t numbers;
    struct TPMBootMeasureData report[32];
} ;

#ifdef __cplusplus
extern "C" {
#endif


int TPM_GetTrustedRootData(struct TPMTrustedRootData *data);
int TPM_GetBootMeasureStatus();
int TPM_GetBootMeasureCfgStatus();
int TPM_SetBootMeasureCfgStatus(int status);
int TPM_SetReCollectMeasureStandarValue(int status);
int TPM_GetReCollectMeasureStandarValue();
int TPM_GetBootMeasureData(struct TPMBootMeasureData **list, int *count);
int TPM_GetHistoryBootMeasureLog(struct TPMBootMeasureLog **list, int *count);

int TPM_GetBootMode();
int TPM_SetBootMode(int status);
int TPM_SaveFlashBootMeasureLog(); 

#ifdef __cplusplus
}
#endif


#endif //__TPM_SECURITY_H__
